OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} ha cambiato la tua password",
    "You changed your password" : "Hai cambiato la tua password",
    "Your password was reset by an administrator" : "La tua password è stata reimpostata da un amministratore",
    "{actor} changed your email address" : "{actor} ha cambiato il tuo indirizzo email",
    "You changed your email address" : "Hai cambiato il tuo indirizzo email",
    "Your email address was changed by an administrator" : "Il tuo indirizzo email è stato cambiato da un amministratore",
    "Security" : "Sicurezza",
    "Your apps" : "Le tue applicazioni",
    "Enabled apps" : "Applicazioni abilitate",
    "Disabled apps" : "Applicazioni disabilitate",
    "Wrong password" : "Password errata",
    "Saved" : "Salvato",
    "No user supplied" : "Non è stato fornito alcun utente",
    "Unable to change password" : "Impossibile cambiare la password",
    "Authentication error" : "Errore di autenticazione",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Fornisci una password amministrativa di ripristino; altrimenti, tutti i dati degli utenti saranno persi.",
    "Wrong admin recovery password. Please check the password and try again." : "Password amministrativa di ripristino errata. Controlla la password e prova ancora.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installazione e aggiornamento delle applicazioni tramite il negozio delle applicazioni o condivisione cloud federata",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilizza una versione %s datata (%s). Aggiorna il tuo sistema operativo o funzionalità come %s non funzioneranno correttamente.",
    "A problem occurred, please check your log files (Error: %s)" : "Si è verificato un problema, controlla i tuoi file di log (Errore: %s)",
    "Migration Completed" : "Migrazione completata",
    "Group already exists." : "Il gruppo esiste già.",
    "Unable to add group." : "Impossibile aggiungere il gruppo.",
    "Unable to delete group." : "Impossibile eliminare il gruppo.",
    "Invalid SMTP password." : "Password SMTP non valida.",
    "Well done, %s!" : "Ben fatto, %s!",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Si è verificato un problema durante l'invio dell'email. Controlla le tue impostazioni. (Errore: %s)",
    "You need to set your user email before being able to send test emails." : "Devi impostare l'indirizzo del tuo utente prima di poter provare l'invio delle email.",
    "Invalid mail address" : "Indirizzo email non valido",
    "No valid group selected" : "Nessun gruppo valido selezionato",
    "A user with that name already exists." : "Un utente con quel nome esiste già.",
    "To send a password link to the user an email address is required." : "Per inviare un collegamento della password all'utente è richiesto un indirizzo email.",
    "Unable to create user." : "Impossibile creare l'utente.",
    "Unable to delete user." : "Impossibile eliminare l'utente.",
    "Error while enabling user." : "Errore durante l'abilitazione dell'utente.",
    "Error while disabling user." : "Errore durante la disabilitazione dell'utente.",
    "Settings saved" : "Impostazioni salvate",
    "Unable to change full name" : "Impossibile cambiare il nome completo",
    "Unable to change email address" : "Impossibile cambiare l'indirizzo di posta",
    "Your full name has been changed." : "Il tuo nome completo è stato cambiato.",
    "Forbidden" : "Vietato",
    "Invalid user" : "Utente non valido",
    "Unable to change mail address" : "Impossibile cambiare l'indirizzo di posta",
    "Email saved" : "Email salvata",
    "%1$s changed your password on %2$s." : "%1$s ha cambiato la tua password su %2$s.",
    "Your password on %s was changed." : "La tua password su %s è stata modificata.",
    "Password changed for %s" : "Password modificata per %s",
    "If you did not request this, please contact an administrator." : "Se non lo hai richiesto, contatta un amministratore.",
    "Password for %1$s changed on %2$s" : "Password per %1$s cambiata su %2$s",
    "The new email address is %s" : "Il nuovo indirizzo email è %s",
    "Welcome aboard" : "Benvenuto a bordo",
    "Welcome aboard %s" : "Benvenuto a bordo di %s",
    "Your username is: %s" : "Il tuo nome utente è: %s",
    "Set your password" : "Imposta la tua password",
    "Go to %s" : "Vai a %s",
    "Install Client" : "Installa client",
    "Your %s account was created" : "Il tuo account %s è stato creato",
    "Password confirmation is required" : "La conferma della password è richiesta",
    "Couldn't remove app." : "Impossibile rimuovere l'applicazione.",
    "Couldn't update app." : "Impossibile aggiornate l'applicazione.",
    "Are you really sure you want add {domain} as trusted domain?" : "Sei davvero sicuro di voler aggiungere {domain}  come dominio attendibile?",
    "Add trusted domain" : "Aggiungi dominio attendibile",
    "Migration in progress. Please wait until the migration is finished" : "Migrazione in corso. Attendi fino al completamento della migrazione",
    "Migration started …" : "Migrazione avviata...",
    "Not saved" : "Non salvato",
    "Sending…" : "Invio in corso...",
    "Email sent" : "Email inviata",
    "Official" : "Ufficiale",
    "All" : "Tutti",
    "Update to %s" : "Aggiornato a %s",
    "_You have %n app update pending_::_You have %n app updates pending_" : ["Hai %n aggiornamento di applicazione in corso","Hai %n aggiornamenti di applicazione in corso"],
    "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
    "The app will be downloaded from the app store" : "L'applicazione sarà scaricata dallo store delle applicazioni",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Le applicazioni ufficiali sono sviluppate dalla comunità. Esse offrono nuove  funzionalità e sono pronte per l'uso in produzione.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Le applicazioni approvate sono sviluppate da sviluppatori affidabili e hanno passato un rapido controllo di sicurezza. Sono attivamente mantenute in un deposito aperto del codice e i loro responsabili le ritengono pronte sia per un utilizzo casuale che per un utilizzo continuativo.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Questa applicazione non è stata sottoposta a controlli di sicurezza, è nuova o notoriamente instabile. Installala a tuo rischio.",
    "Disabling app …" : "Disabilitazione applicazione...",
    "Error while disabling app" : "Errore durante la disattivazione",
    "Disable" : "Disabilita",
    "Enable" : "Abilita",
    "Enabling app …" : "Abilitazione applicazione...",
    "Error while enabling app" : "Errore durante l'attivazione",
    "Error while disabling broken app" : "Errore durante la disabilitazione dell'applicazione danneggiata",
    "Updating...." : "Aggiornamento in corso...",
    "Error while updating app" : "Errore durante l'aggiornamento",
    "Updated" : "Aggiornato",
    "Removing …" : "Rimozione in corso...",
    "Error while removing app" : "Errore durante la rimozione dell'applicazione",
    "Remove" : "Rimuovi",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'applicazione è stata abilitata, ma deve essere aggiornata. Sarai rediretto alla pagina di aggiornamento in 5 secondi.",
    "App update" : "Aggiornamento applicazione",
    "Approved" : "Approvata",
    "Experimental" : "Sperimentale",
    "No apps found for {query}" : "Nessuna applicazione trovata per {query}",
    "Enable all" : "Abilita tutto",
    "Allow filesystem access" : "Consenti accesso al filesystem",
    "Disconnect" : "Disconnetti",
    "Revoke" : "Revoca",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome per Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "Client iOS",
    "Android Client" : "Client Android",
    "Sync client - {os}" : "Client di sincronizzazione - {os}",
    "This session" : "Questa sessione",
    "Copy" : "Copia",
    "Copied!" : "Copiato!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "Error while loading browser sessions and device tokens" : "Errore durante il caricamento delle sessioni del browser e dei token di dispositivo",
    "Error while creating device token" : "Errore durante la creazione del token di dispositivo",
    "Error while deleting the token" : "Errore durante l'eliminazione del token",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Si è verificato un errore. Carica un certificato PEM codificato in ASCII.",
    "Valid until {date}" : "Valido fino al {date}",
    "Delete" : "Elimina",
    "Local" : "Locale",
    "Private" : "Privato",
    "Only visible to local users" : "Visibile solo agli utenti locali",
    "Only visible to you" : "Visibile solo a te",
    "Contacts" : "Contatti",
    "Visible to local users and to trusted servers" : "Visibile agli utenti locali e ai server affidabili",
    "Public" : "Pubblico",
    "Will be synced to a global and public address book" : "Sarà sincronizzato con una rubrica globale e pubblica",
    "Verify" : "Verifica",
    "Verifying …" : "Verifica in corso...",
    "Select a profile picture" : "Seleziona un'immagine del profilo",
    "Very weak password" : "Password molto debole",
    "Weak password" : "Password debole",
    "So-so password" : "Password così-così",
    "Good password" : "Password buona",
    "Strong password" : "Password forte",
    "Groups" : "Gruppi",
    "Unable to delete {objName}" : "Impossibile eliminare {objName}",
    "Error creating group: {message}" : "Errore durante la creazione del gruppo: {message}",
    "A valid group name must be provided" : "Deve essere fornito un nome valido per il gruppo",
    "deleted {groupName}" : "{groupName} eliminato",
    "undo" : "annulla",
    "never" : "mai",
    "deleted {userName}" : "{userName} eliminato",
    "No user found for <strong>{pattern}</strong>" : "Nessun utente trovato per <strong>{pattern}</strong>",
    "Unable to add user to group {group}" : "Impossibile aggiungere l'utente al gruppo {group}",
    "Unable to remove user from group {group}" : "Impossibile rimuovere l'utente dal gruppo {group}",
    "Add group" : "Aggiungi gruppo",
    "Invalid quota value \"{val}\"" : "Valore di quota \"{val}\" non valido",
    "no group" : "nessun gruppo",
    "Password successfully changed" : "Password modificata correttamente",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Il cambiamento della password causerà una perdita di dati, poiché il ripristino dei dati non è disponibile per questo utente",
    "Could not change the users email" : "Impossibile modificare l'indirizzo email degli utenti",
    "A valid username must be provided" : "Deve essere fornito un nome utente valido",
    "Error creating user: {message}" : "Errore durante la creazione dell'utente: {message}",
    "A valid password must be provided" : "Deve essere fornita una password valida",
    "A valid email must be provided" : "Deve essere fornito un indirizzo email valido",
    "Developer documentation" : "Documentazione dello sviluppatore",
    "Limit to groups" : "Limita a gruppi",
    "This app has an update available." : "Un aggiornamento di questa applicazione è disponibile.",
    "by %s" : "di %s",
    "%s-licensed" : "sotto licenza %s",
    "Documentation:" : "Documentazione:",
    "User documentation" : "Documentazione utente",
    "Admin documentation" : "Documentazione di amministrazione",
    "Visit website" : "Visita il sito web",
    "Report a bug" : "Segnala un bug",
    "Show description …" : "Mostra descrizione...",
    "Hide description …" : "Nascondi descrizione...",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione minima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione massima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Questa applicazione non può essere installata perché le seguenti dipendenze non sono soddisfatte:",
    "Enable only for specific groups" : "Abilita solo per gruppi specifici",
    "SSL Root Certificates" : "Certificati radice SSL",
    "Common Name" : "Nome comune",
    "Valid until" : "Valido fino al",
    "Issued By" : "Emesso da",
    "Valid until %s" : "Valido fino al %s",
    "Import root certificate" : "Importa certificato radice",
    "Administrator documentation" : "Documentazione amministratore",
    "Online documentation" : "Documentazione in linea",
    "Forum" : "Forum",
    "Getting help" : "Ottenere aiuto",
    "Commercial support" : "Supporto commerciale",
    "None" : "Nessuno",
    "Login" : "Accesso",
    "Plain" : "Semplice",
    "NT LAN Manager" : "Gestore NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Server di posta",
    "Open documentation" : "Apri la documentazione",
    "Send mode" : "Modalità di invio",
    "Encryption" : "Cifratura",
    "From address" : "Indirizzo mittente",
    "mail" : "posta",
    "Authentication method" : "Metodo di autenticazione",
    "Authentication required" : "Autenticazione richiesta",
    "Server address" : "Indirizzo del server",
    "Port" : "Porta",
    "Credentials" : "Credenziali",
    "SMTP Username" : "Nome utente SMTP",
    "SMTP Password" : "Password SMTP",
    "Store credentials" : "Memorizza le credenziali",
    "Test email settings" : "Prova impostazioni email",
    "Send email" : "Invia email",
    "Server-side encryption" : "Cifratura lato server",
    "Enable server-side encryption" : "Abilita cifratura lato server",
    "Please read carefully before activating server-side encryption: " : "Leggi attentamente prima di attivare la cifratura lato server:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Quando la cifratura è abilitata, tutti i file caricati sul server da quel momento in poi saranno cifrati sul server. Sarà possibile solo disabilitare successivamente la cifratura se il modulo di cifratura attivo lo consente, e se tutti i prerequisiti (ad es. l'impostazione di una chiave di recupero) sono verificati.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La sola cifratura non garantisce la sicurezza del sistema. Leggi la documentazione per ottenere ulteriori informazioni sul funzionamento dell'applicazione di cifratura.",
    "Be aware that encryption always increases the file size." : "Considera che la cifratura incrementa sempre la dimensione dei file.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ti consigliamo di creare copie di sicurezza dei tuoi dati con regolarità, in caso di utilizzo della cifratura, assicurati di creare una copia delle chiavi di cifratura insieme ai tuoi dati.",
    "This is the final warning: Do you really want to enable encryption?" : "Questo è l'ultimo avviso: vuoi davvero abilitare la cifratura?",
    "Enable encryption" : "Abilita cifratura",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nessun modulo di cifratura caricato, carica un modulo di cifratura nel menu delle applicazioni.",
    "Select default encryption module:" : "Seleziona il modulo di cifratura predefinito:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Devi migrare le tue chiavi di cifratura dalla vecchia cifratura (ownCloud <= 8.0) alla nuova. Abilita il \"Modulo di cifratura predefinito\" ed esegui 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Devi migrare le tue chiavi di cifratura dalla vecchia cifratura (ownCloud <= 8.0) alla nuova.",
    "Start migration" : "Avvia migrazione",
    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configurazione di sola lettura è stata abilitata. Ciò impedisce l'impostazione di alcune configurazioni tramite l'interfaccia web. Inoltre, i file devono essere resi scrivibili manualmente per ogni aggiornamento.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Il tuo database non è in esecuzione con il livello di isolamento delle transazioni \"READ COMMITTED\". Ciò può causare problemi quando diverse azioni sono eseguite in parallelo.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale è disabilitato, ciò potrebbe comportare problemi di race condition. Abilita 'filelocking.enabled' nel config-php per evitare questi problemi. Vedi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
    "System locale can not be set to a one which supports UTF-8." : "La localizzazione di sistema non può essere impostata a una che supporta UTF-8.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Leggi attentamente le  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"%s\">log</a>.",
    "All checks passed." : "Tutti i controlli passati.",
    "Execute one task with each page loaded" : "Esegui un'operazione con ogni pagina caricata",
    "The cron.php needs to be executed by the system user \"%s\"." : "Il cron.php deve essere eseguito dall'utente di sistema \"%s\".",
    "Version" : "Versione",
    "Sharing" : "Condivisione",
    "Allow apps to use the Share API" : "Consenti alle applicazioni di utilizzare le API di condivisione",
    "Allow users to share via link" : "Consenti agli utenti di condividere tramite collegamento",
    "Allow public uploads" : "Consenti caricamenti pubblici",
    "Always ask for a password" : "Chiedi sempre una password",
    "Enforce password protection" : "Imponi la protezione con password",
    "Set default expiration date" : "Imposta data di scadenza predefinita",
    "Expire after " : "Scadenza dopo",
    "days" : "giorni",
    "Enforce expiration date" : "Forza la data di scadenza",
    "Allow resharing" : "Consenti la ri-condivisione",
    "Allow sharing with groups" : "Consenti la condivisione con gruppi",
    "Restrict users to only share with users in their groups" : "Limita gli utenti a condividere solo con gli utenti nei loro gruppi",
    "Exclude groups from sharing" : "Escludi gruppi dalla condivisione",
    "These groups will still be able to receive shares, but not to initiate them." : "Questi gruppi saranno in grado di ricevere condivisioni, ma non iniziarle.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Consenti il completamento del nome utente nella finestra di condivisione. Se è disabilitata, è necessario digitare il nome utente completo.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Mostra il testo di liberatoria sulla pagina di caricamento del collegamento pubblico. (Mostrato solo quando l'elenco dei file nascosto)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Questo testo sarà mostrato sulla pagina di caricamento del collegamento pubblico quando l'elenco dei file è nascosto.",
    "Tips & tricks" : "Suggerimenti e trucchi",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite è utilizzato attualmente come database. Per installazioni più grandi consigliamo di passare a un motore di database diverso.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Consigliato particolarmente quando si utilizza il client desktop per la sincronizzazione dei file.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Per migrare a un altro database, usa lo strumento da riga di comando: 'occ db:convert-type', o leggi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione ↗</a>.",
    "How to do backups" : "Come creare delle copie di sicurezza",
    "Advanced monitoring" : "Monitoraggio avanzato",
    "Performance tuning" : "Ottimizzazione delle prestazioni",
    "Improving the config.php" : "Ottimizzare il config.php",
    "Theming" : "Temi",
    "Check the security of your Nextcloud over our security scan" : "Controlla la sicurezza del tuo Nextcloud con la nostra scansione di sicurezza",
    "Hardening and security guidance" : "Guida alla messa in sicurezza",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Stai utilizzando <strong>%s</strong> di <strong>%s</strong>",
    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Stai utilizzando <strong>%s</strong> di <strong>%s</strong> (strong>%s %%</strong>)",
    "Profile picture" : "Immagine del profilo",
    "Upload new" : "Carica nuova",
    "Select from Files" : "Seleziona da file",
    "Remove image" : "Rimuovi immagine",
    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
    "Picture provided by original account" : "Immagine fornita dall'account originale",
    "Cancel" : "Annulla",
    "Choose as profile picture" : "Scegli come immagine del profilo",
    "Full name" : "Nome completo",
    "No display name set" : "Nome visualizzato non impostato",
    "Email" : "Posta elettronica",
    "Your email address" : "Il tuo indirizzo email",
    "No email address set" : "Nessun indirizzo email impostato",
    "For password reset and notifications" : "Per ripristino della password e notifiche",
    "Phone number" : "Numero di telefono",
    "Your phone number" : "Il tuo numero di telefono",
    "Address" : "Indirizzo",
    "Your postal address" : "Il tuo indirizzo postale",
    "Website" : "Sito web",
    "Link https://…" : "Colegamento https://...",
    "Twitter" : "Twitter",
    "You are member of the following groups:" : "Sei membro dei seguenti gruppi:",
    "Language" : "Lingua",
    "Help translate" : "Migliora la traduzione",
    "Password" : "Password",
    "Current password" : "Password attuale",
    "New password" : "Nuova password",
    "Change password" : "Modifica password",
    "Web, desktop and mobile clients currently logged in to your account." : "Client web, desktop e mobile attualmente connessi al tuo account.",
    "Device" : "Dispositivo",
    "Last activity" : "Ultima attività",
    "App name" : "Nome applicazione",
    "Create new app password" : "Crea nuova password di applicazione",
    "Use the credentials below to configure your app or device." : "Utilizza le credenziali in basso per configurare la tua applicazione o dispositivo.",
    "For security reasons this password will only be shown once." : "Per motivi di sicurezza questa password sarà mostra solo una volta.",
    "Username" : "Nome utente",
    "Done" : "Completato",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sviluppato dalla {communityopen}comunità di Nextcloud{linkclose}, il {githubopen}codice sorgente{linkclose} è rilasciato nei termini della licenza {licenseopen}AGPL{linkclose}.",
    "Settings" : "Impostazioni",
    "Show storage location" : "Mostra posizione di archiviazione",
    "Show user backend" : "Mostra il motore utente",
    "Show last login" : "Mostra ultimo accesso",
    "Show email address" : "Mostra l'indirizzo email",
    "Send email to new user" : "Invia email al nuovo utente",
    "E-Mail" : "Posta elettronica",
    "Create" : "Crea",
    "Admin Recovery Password" : "Password di ripristino amministrativa",
    "Enter the recovery password in order to recover the users files during password change" : "Digita la password di ripristino per recuperare i file degli utenti durante la modifica della password.",
    "Group name" : "Nome del gruppo",
    "Everyone" : "Chiunque",
    "Admins" : "Amministratori",
    "Disabled" : "Disabilitati",
    "Default quota" : "Quota predefinita",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Digita la quota di archiviazione (ad es.: \"512 MB\" or \"12 GB\")",
    "Unlimited" : "Illimitata",
    "Other" : "Altro",
    "Group admin for" : "Amministratore per il gruppo",
    "Quota" : "Quote",
    "Storage location" : "Posizione di archiviazione",
    "User backend" : "Motore utente",
    "Last login" : "Ultimo accesso",
    "change full name" : "modica nome completo",
    "set new password" : "imposta una nuova password",
    "change email address" : "cambia l'indirizzo email",
    "Default" : "Predefinito",
    "Enabled" : "Abilitata",
    "Not enabled" : "Non abilitata",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Fornisci una password amministrativa di ripristino altrimenti tutti i dati degli utenti saranno persi.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Il motore non supporta la modifica della password, ma la chiave di cifratura dell'utente è stata aggiornata correttamente.",
    "test email settings" : "prova impostazioni email",
    "Invalid request" : "Richiesta non valida",
    "Admins can't remove themself from the admin group" : "Gli amministratori non possono rimuovere se stessi dal gruppo di amministrazione",
    "Unable to add user to group %s" : "Impossibile aggiungere l'utente al gruppo %s",
    "Unable to remove user from group %s" : "Impossibile rimuovere l'utente dal gruppo %s",
    "Sending..." : "Invio in corso...",
    "Uninstalling ...." : "Disinstallazione...",
    "Error while uninstalling app" : "Errore durante la disinstallazione dell'applicazione",
    "Uninstall" : "Disinstalla",
    "__language_name__" : "Italiano",
    "Personal info" : "Informazioni personali",
    "Sessions" : "Sessioni",
    "App passwords" : "Password di applicazione",
    "Sync clients" : "Client di sincronizzazione",
    "This is used for sending out notifications." : "Viene utilizzato per inviare le notifiche.",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php non sembra essere configurato correttamente per interrogare le variabili d'ambiente di sistema. Il test con getenv(\"PATH\") restituisce solo una risposta vuota.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Controlla la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione di installazione↗</a>  per le note di configurazione di php e la configurazione del tuo server, in particolare quando utilizzi php-fpm.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "La versione di %1$s installata è anteriore alla %2$s, per motivi di stabilità e prestazioni, consigliamo di aggiornare a una versione di %1$s più recente.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Il modulo PHP 'fileinfo' non è presente. Consigliamo vivamente di abilitare questo modulo per ottenere risultati migliori con il rilevamento dei tipi MIME.",
    "This means that there might be problems with certain characters in file names." : "Ciò significa che potrebbero esserci problemi con alcuni caratteri nei nomi dei file.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Consigliamo vivamente di installare i pacchetti richiesti sul tuo sistema per supportare una delle localizzazioni seguenti: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se la tua installazione non si trova nella radice del dominio e utilizza il cron di sistema, potrebbero esserci problemi con la generazione degli URL. Per evitare questi problemi, imposta l'opzione \"overwrite.cli.url\"  nel file config.php al percorso della radice del sito della tua installazione (Consigliato: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Non è stato possibile eseguire il job di cron tramite CLI. Sono apparsi i seguenti errori tecnici:",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Ultima esecuzione di cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Ultima esecuzione di cron: %s. Potrebbe esserci un problema.",
    "Cron was not executed yet!" : "Cron non è stato ancora eseguito!",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php è registrato su un servizio webcron per invocare cron.php ogni 15 minuti su http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usa il servizio cron di sistema per invocare il file cron.php ogni 15 minuti.",
    "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "Per eseguirlo, hai bisogno dell'estensione posix di PHP. Vedi la {linkstart}documentazione di PHP{linkend} per ulteriori dettagli.",
    "Uninstall app" : "Disinstalla applicazione",
    "Hey there,<br><br>just letting you know that you now have a %s account.<br><br>Your username: <strong>%s</strong><br>Access it: <strong><a href=\"%s\">%s</a></strong><br><br>" : "Ciao,<br><br>volevamo informarti che ora hai un account %s.<br><br>Il tuo nome utente: <strong>%s</strong><br>Accedi: <strong><a href=\"%s\">%s</a></strong><br><br>",
    "Cheers!" : "Saluti!",
    "Hey there,\n\njust letting you know that you now have a %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ciao,\n\nvolevamo informarti che ora hai un account %s.\n\nIl tuo nome utente: %s\nAccedi: %s\n\n",
    "For password recovery and notifications" : "Per il ripristino della password e per le notifiche",
    "Your website" : "Il tuo sito web",
    "Your Twitter handle" : "Il tuo nome utente su Twitter",
    "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
    "Desktop client" : "Client desktop",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Se vuoi supportare il progetto {contributeopen}unisciti allo sviluppo{linkclose} o {contributeopen} diffondi il verbo{linkclose}!",
    "Show First Run Wizard again" : "Mostra nuovamente la procedura di primo avvio",
    "Passcodes that give an app or device permissions to access your account." : "Codici di accesso per fornire alle applicazioni o ai dispositivi il permesso di accedere al tuo account.",
    "Name" : "Nome",
    "Follow us on Google Plus!" : "Seguici su Google Plus!",
    "Like our facebook page!" : "Mi piace sulla nostra pagina di Facebook!",
    "Subscribe to our twitter channel!" : "Iscriviti al nostro canale twitter!",
    "Subscribe to our news feed!" : "Iscriviti alla nostra fonte di notizie!",
    "Subscribe to our newsletter!" : "Iscriviti alla nostra newsletter!",
    "Show last log in" : "Mostra ultimo accesso",
    "Follow us on Google+!" : "Seguici su Google+!",
    "Follow us on Twitter!" : "Seguici su Twitter!",
    "Check out our blog!" : "Leggi il nostro blog!"
},
"nplurals=2; plural=(n != 1);");
